#
# spec file for package python-polib
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2013 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-polib
Version:        1.2.0
Release:        3.4
Summary:        A library to manipulate gettext files
License:        MIT
URL:            https://github.com/izimobil/polib/
Source0:        https://files.pythonhosted.org/packages/source/p/polib/polib-%{version}.tar.gz
Patch0:         polib-1.1.0-fix-tests-big-endian.patch
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gettext-runtime >= 0.19.8
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
polib allows you to manipulate, create, modify gettext catalogs (.pot, .po and
binary .mo files). You can load existing files, iterate through it's entries,
add, modify entries, comments or metadata, etc... or create new po/pot files
from scratch.

polib provides a simple and pythonic API, exporting only two convenience
functions 'pofile' and 'mofile', and the 4 core classes: POFile, MOFile,
POEntry and MOEntry for creating new files/entries.

%package -n python-polib-doc
Summary:        A library to manipulate gettext files - documentation
Group:          Documentation/Other
Provides:       %{python_module polib-doc = %{version}}

%description -n python-polib-doc
polib allows you to manipulate, create, modify gettext catalogs (.pot, .po and
binary .mo files). You can load existing files, iterate through it's entries,
add, modify entries, comments or metadata, etc... or create new po/pot files
from scratch.

polib provides a simple and pythonic API, exporting only two convenience
functions 'pofile' and 'mofile', and the 4 core classes: POFile, MOFile,
POEntry and MOEntry for creating new files/entries.

This package contains documentation in HTML format.

%prep
%autosetup -p1 -n polib-%{version}

%build
%pyproject_wheel

pushd docs
make %{?_smp_mflags} html
rm _build/html/.buildinfo
popd

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# https://github.com/izimobil/polib/issues/150
%pytest tests/tests.py -k 'not (test_save_as_mofile or test_is_file)'

%files %{python_files}
%license LICENSE
%doc CHANGELOG README.rst
%{python_sitelib}/polib.py
%pycache_only %{python_sitelib}/__pycache__/polib.*pyc
%{python_sitelib}/polib-%{version}.dist-info

%files -n python-polib-doc
%doc docs/_build/html

%changelog
* Mon Mar 18 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to autosetup and pytest macros.
- Skip two broken tests.
* Thu Feb  1 2024 Ben Greiner <code@bnavigator.de>
- Fix multibuild
* Sat Jan 13 2024 Axel Braun <axel.braun@gmx.de>
- Switch to wheel and %%{?sle15_python_module_pythons}
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 1.2.0:
  * Added setter for the fuzzy property
  * Escape/unescape ^k, ^h and ^l
  * Added path to error message processing parser symbols
  * Ensure empty previous values for msgid and msgstr are
    properly saved
  * Fixed relative ordering of comments and translator
    comments
  * Do not count obsolete entries in fuzzy() method
  * Close files properly
  * Fixed support for loading mo files from bytes object
  * Fixed msgstr_plural comparison
  * Simplified python version check
  * Updated docs
* Thu Aug  3 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Sun Jun  6 2021 Dirk Müller <dmueller@suse.com>
- update to 1.1.1:
  - Strip UTF-16 BOM (U+FEFF) from start of file
  - Message context (msgctxt) support for MO files
  - Dropped Python < 2.7 support
  - Updated docs and README after switch from Bitbucket to Github
* Mon Sep 10 2018 Matěj Cepl <mcepl@suse.com>
- Add polib-1.1.0-fix-tests-big-endian.patch to overcome failing tests
  on big-endian machines (https://bitbucket.org/izi/polib/issues/96)
* Thu Jan 25 2018 tchvatal@suse.com
- Version update to 1.1.0:
  - Fixed entries sorting when generating mo file (Fixes #78)
  - Fixed find method (Fixes #84)
  - Refactored POEntry.__cmp__ method (this should fix issues #60, #65 and #79)
  - Fixed duplicated entries when merging po file with pot file (fixes #68)
  - Fixed "None" string being outputted when polib deals with syntax error in string (Fixes issue #66)
  - Added a fuzzy property to entries (Fixes #76)
  - Take into account the message context when comparing entries
  - Leave occurence untouched if line number is not a number (fixes #80 and #90)
  - Fixed test for mo files that was failing because since gettext version 0.19.8.1, msgfmt skips the "POT-Creation-Date" metadata entry (Fixes #86)
  - Fixed major revision number comparison
  - Dropped python 2.4 support
- Drop merged patch 2a4caf09e210554018bf0e928690d9617ff89e00.diff
* Mon Dec  4 2017 mlin@suse.com
- Add upstream patch 2a4caf09e210554018bf0e928690d9617ff89e00.diff
  * Fixed test for mo files that was failing because since gettext
    version 0.19.8.1, msgfmt skips the "POT-Creation-Date" metadata
    entry.
* Sun Apr 23 2017 toddrme2178@gmail.com
- Update to version 1.0.8
  * Fixed issue #70 (occurrences parsing for windows pathes)
  * Fixed issue #71 (tcomment and flags not saved for obsolete entries)
  * Fixed issue #72 (wrong metadata ordering)
  * Fixed issue #73 (can't always unpickle POFile)
  * Use natural sorting for additional headers (metadata)
  * Fixed typos in various documents
- Update to version 1.0.7
  * Fixed bad parsing of indented msgstr_plural
  * Fixed ordering of "Language" metadata entry
  * Removed space after "#" in header if comment line is empty (like gettext tools)
  * Fixed typos / grammar errors (thanks Jakub Wilk)
  * Take into account msgid_plural if needed when comparing entries (thanks Leonardo Constantino Oliveira)
  * Fixed issue #63 (str() on a bytes instance when using python3) (thanks Jakub Wilk)
- Implement single-spec version
- Fix source url.
* Mon May 11 2015 benoit.monin@gmx.fr
- update to version 1.0.6:
  * Wheel support
  * Add missing 'Language' and 'Plural-Forms' to metadata ordering
  * More accurate float operation for POFile.percent_translated()
- additional changes from version 1.0.5:
  * Fixed issue #59: tokens variable referenced before assignment
  * Implemented feature request #56: line number information in PO
    entries
  * Fixed issue #61: polib does not handle previous msgid on
    multines properly
- additional changes from version 1.0.4:
  * Fixed issue #43: improved check that determine if polib is
    dealing with a filepath or unicode content
  * Fixed issue #44: polib now checks MO files revision number and
    throws an error if the number is unexpected
  * Fixed issue #45: parse properly mo files with no header entry
  * Fixed issue #47: added flags attribute for MOEntry to be
    consistant with POEntry
  * Fixed issue #49: use integers rather than strings for
    msgstr_plural keys
  * Fixed issue #51: if a PO file ends with a comment, polib adds a
    spurious empty entry at the end
  * Fixed issue #52: bad magic number written on big endian
    platforms
  * Fixed issue #53: added a __hash__() method to POEntry and
    MOEntry classes
  * Fixed issue #54: use lowercase for state identifiers. This
    fixes issues with certain locales and string.lower()
  * Fixed issue #58: use io.open() instead of codecs.open() because
    the latter doesn't handle very well universal line endings
  * Make sure the mo file is closed at garbage collection, this
    prevents warnings on unclosed file when running tests with
    python >= 3.2
  * Better way to test indianness
  * polib download URL is now on Pypi
- drop endian_magic.patch: fixed upstream
- point the source URL to pypi
* Thu Sep 12 2013 dvaleev@suse.com
- Fixed issue #53 (bad magic number written on big endian platforms)
  endian_magic.patch
* Mon Feb 11 2013 lazy.kent@opensuse.org
- Correct RPM group.
- Use full URL as a source.
- Doesn't require fdupes.
* Sat Feb  9 2013 p.drouand@gmail.com
- Update to 1.0.3
  * Fixed issue #38: POFile.append() raised a duplicate exception when
    you tried to add a new entry with the same msgid and a different msgctxt
    (only when check_for_duplicates option is set to True)
  * Fixed issue #39: Added __init__.py file for convenience
  * Fixed issue #41: UnicodeDecodeError when running setup.py build on
    python3 with C locale
  * polib is now fully PEP8 compliant
  * Small improvements: remove unused "typ" var, mproved Makefile, Make sure
    BaseFile.__contains__ returns a boolean value
* Wed Sep 12 2012 os-dev@jacraig.com
- Update to 1.0.1:
  * speed up POFile.merge method
  * allow comments starting with two '#' characters
* Wed Jun 13 2012 os-dev@jacraig.com
- Update to 1.0.0:
  * polib.pofile and polib.mofile functions can now return a custom class
    (thanks Craig Blaszczyk)
  * polib now can find the metadata entry no matter where it is located (thanks
    François Poirotte)
  * fixed issue #28 (IOError on reading obsolete "previous msgid" entries)
    (thanks James Ni)
  * Dropped python 2.4 support
- Add %%check section to run unit tests
* Tue Jan 31 2012 saschpe@suse.de
- Resolved spec file conflict
- Remove obsolete SUSE version check (for 10.1)
* Tue Aug 16 2011 saschpe@suse.de
- Fix build on SLE_10 by adding a version check around fdupes and
  by removing the %%check section
* Mon Aug 15 2011 saschpe@suse.de
- Spec file cleanup:
  * Remove authors from description
  * Much simpler docs generation and installation (don't install
    Makefile and reStructuredText sources)
* Sun Aug 14 2011 hpj@urpla.net
- install docs in the package doc dir
* Sat Aug 13 2011 hpj@urpla.net
- Release 0.7.0
- create and package docs
* Mon Sep 20 2010 fcrozat@novell.com
- Release 0.5.3
